# hamcws

A python based async wrapper around J River [MCWS](https://wiki.jriver.com/index.php/Web_Service_Interface) designed for use
by a [Home Assistant](https://www.home-assistant.io/) integration.

